@@ -13,7 +13,7 @@ LaunchCLIOptions = AskCLIOptions = ClipboardCLIOptions = DiffCLIOptions = CLIOpt
 HintsCLIOptions = IcatCLIOptions = PanelCLIOptions = ResizeCLIOptions = CLIOptions
 ErrorCLIOptions = UnicodeCLIOptions = RCOptions = RemoteFileCLIOptions = CLIOptions
 QueryTerminalCLIOptions = BroadcastCLIOptions = ShowKeyCLIOptions = CLIOptions
-ThemesCLIOptions = TransferCLIOptions = CopyCLIOptions = CLIOptions
+ThemesCLIOptions = TransferCLIOptions = LoadConfigRCOptions = ActionRCOptions = CLIOptions
 
 
 def generate_stub() -> None:
@@ -66,9 +66,6 @@ def generate_stub() -> None:
     from kittens.resize_window.main import OPTIONS
     do(OPTIONS(), 'ResizeCLIOptions')
 
-    from kittens.show_error.main import OPTIONS
-    do(OPTIONS(), 'ErrorCLIOptions')
-
     from kittens.unicode_input.main import OPTIONS
     do(OPTIONS(), 'UnicodeCLIOptions')
 
@@ -78,9 +75,6 @@ def generate_stub() -> None:
     from kittens.transfer.main import option_text as OPTIONS
     do(OPTIONS(), 'TransferCLIOptions')
 
-    from kittens.ssh.copy import option_text as OPTIONS
-    do(OPTIONS(), 'CopyCLIOptions')
-
     from kitty.rc.base import all_command_names, command_for_name
     for cmd_name in all_command_names():
         cmd = command_for_name(cmd_name)
